@@ -9,10 +9,9 @@ package Inline::CPP;
 #============================================================================
 
 use strict;
-BEGIN{ require Parse::RecDescent; }
-BEGIN{ require Inline::CPP::grammar; }
+
 require Inline::C;
-#require Inline::CPP::grammar;
+require Inline::CPP::grammar;
 use Carp;
 
 use vars qw(@ISA $VERSION);
@@ -20,7 +19,7 @@ use vars qw(@ISA $VERSION);
 @ISA = qw(Inline::C);
 
 # Development releases will have a _0xx version suffix.
-$VERSION = '0.33_008';
+$VERSION = '0.33_009';
 $VERSION = eval $VERSION; # To accommodate dev. version numbers.
 
 
@@ -217,7 +216,7 @@ sub get_parser {
     my $grammar = Inline::CPP::grammar::grammar()
         or croak "Can't find C++ grammar\n";
     $::RD_HINT++;
-#    require Parse::RecDescent;
+    require Parse::RecDescent;
     my $parser = Parse::RecDescent->new($grammar);
     $parser->{data}{typeconv} = $o->{ILSM}{typeconv};
     $parser->{ILSM} = $o->{ILSM}; # give parser access to config options
